==> google-cloud-datacatalog-3.0.0.tar.gz: google-cloud-datacatalog-3.0.0/google/cloud/datacatalog_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .timestamps import SystemTimestamps
from .gcs_fileset_spec import (
    GcsFilesetSpec,
    GcsFileSpec,
)
from .schema import (
    Schema,
    ColumnSchema,
)
from .search import SearchCatalogResult
from .table_spec import (
    BigQueryTableSpec,
    ViewSpec,
    TableSpec,
    BigQueryDateShardedSpec,
)
from .tags import (
    Tag,
    TagField,
    TagTemplate,
    TagTemplateField,
    FieldType,
)
from .datacatalog import (
    SearchCatalogRequest,
    SearchCatalogResponse,
    CreateEntryGroupRequest,
    UpdateEntryGroupRequest,
    GetEntryGroupRequest,
    DeleteEntryGroupRequest,
    ListEntryGroupsRequest,
    ListEntryGroupsResponse,
    CreateEntryRequest,
    UpdateEntryRequest,
    DeleteEntryRequest,
    GetEntryRequest,
    LookupEntryRequest,
    Entry,
    EntryGroup,
    CreateTagTemplateRequest,
    GetTagTemplateRequest,
    UpdateTagTemplateRequest,
    DeleteTagTemplateRequest,
    CreateTagRequest,
    UpdateTagRequest,
    DeleteTagRequest,
    CreateTagTemplateFieldRequest,
    UpdateTagTemplateFieldRequest,
    RenameTagTemplateFieldRequest,
    DeleteTagTemplateFieldRequest,
    ListTagsRequest,
    ListTagsResponse,
    ListEntriesRequest,
    ListEntriesResponse,
)
from .policytagmanager import (
    Taxonomy,
    PolicyTag,
    CreateTaxonomyRequest,
    DeleteTaxonomyRequest,
    UpdateTaxonomyRequest,
    ListTaxonomiesRequest,
    ListTaxonomiesResponse,
    GetTaxonomyRequest,
    CreatePolicyTagRequest,
    DeletePolicyTagRequest,
    UpdatePolicyTagRequest,
    ListPolicyTagsRequest,
    ListPolicyTagsResponse,
    GetPolicyTagRequest,
)
from .policytagmanagerserialization import (
    SerializedTaxonomy,
    SerializedPolicyTag,
    ImportTaxonomiesRequest,
    InlineSource,
    ImportTaxonomiesResponse,
    ExportTaxonomiesRequest,
    ExportTaxonomiesResponse,
)


__all__ = (
    "SystemTimestamps",
    "GcsFilesetSpec",
    "GcsFileSpec",
    "Schema",
    "ColumnSchema",
    "SearchCatalogResult",
    "BigQueryTableSpec",
    "ViewSpec",
    "TableSpec",
    "BigQueryDateShardedSpec",
    "Tag",
    "TagField",
    "TagTemplate",
    "TagTemplateField",
    "FieldType",
    "SearchCatalogRequest",
    "SearchCatalogResponse",
    "CreateEntryGroupRequest",
    "UpdateEntryGroupRequest",
    "GetEntryGroupRequest",
    "DeleteEntryGroupRequest",
    "ListEntryGroupsRequest",
    "ListEntryGroupsResponse",
    "CreateEntryRequest",
    "UpdateEntryRequest",
    "DeleteEntryRequest",
    "GetEntryRequest",
    "LookupEntryRequest",
    "Entry",
    "EntryGroup",
    "CreateTagTemplateRequest",
    "GetTagTemplateRequest",
    "UpdateTagTemplateRequest",
    "DeleteTagTemplateRequest",
    "CreateTagRequest",
    "UpdateTagRequest",
    "DeleteTagRequest",
    "CreateTagTemplateFieldRequest",
    "UpdateTagTemplateFieldRequest",
    "RenameTagTemplateFieldRequest",
    "DeleteTagTemplateFieldRequest",
    "ListTagsRequest",
    "ListTagsResponse",
    "ListEntriesRequest",
    "ListEntriesResponse",
    "Taxonomy",
    "PolicyTag",
    "CreateTaxonomyRequest",
    "DeleteTaxonomyRequest",
    "UpdateTaxonomyRequest",
    "ListTaxonomiesRequest",
    "ListTaxonomiesResponse",
    "GetTaxonomyRequest",
    "CreatePolicyTagRequest",
    "DeletePolicyTagRequest",
    "UpdatePolicyTagRequest",
    "ListPolicyTagsRequest",
    "ListPolicyTagsResponse",
    "GetPolicyTagRequest",
    "SerializedTaxonomy",
    "SerializedPolicyTag",
    "ImportTaxonomiesRequest",
    "InlineSource",
    "ImportTaxonomiesResponse",
    "ExportTaxonomiesRequest",
    "ExportTaxonomiesResponse",
)

==> google-cloud-datacatalog-3.1.1.tar.gz: google-cloud-datacatalog-3.1.1/google/cloud/datacatalog_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .datacatalog import (
    CreateEntryGroupRequest,
    CreateEntryRequest,
    CreateTagRequest,
    CreateTagTemplateFieldRequest,
    CreateTagTemplateRequest,
    DeleteEntryGroupRequest,
    DeleteEntryRequest,
    DeleteTagRequest,
    DeleteTagTemplateFieldRequest,
    DeleteTagTemplateRequest,
    Entry,
    EntryGroup,
    GetEntryGroupRequest,
    GetEntryRequest,
    GetTagTemplateRequest,
    ListEntriesRequest,
    ListEntriesResponse,
    ListEntryGroupsRequest,
    ListEntryGroupsResponse,
    ListTagsRequest,
    ListTagsResponse,
    LookupEntryRequest,
    RenameTagTemplateFieldRequest,
    SearchCatalogRequest,
    SearchCatalogResponse,
    UpdateEntryGroupRequest,
    UpdateEntryRequest,
    UpdateTagRequest,
    UpdateTagTemplateFieldRequest,
    UpdateTagTemplateRequest,
    EntryType,
)
from .gcs_fileset_spec import (
    GcsFilesetSpec,
    GcsFileSpec,
)
from .policytagmanager import (
    CreatePolicyTagRequest,
    CreateTaxonomyRequest,
    DeletePolicyTagRequest,
    DeleteTaxonomyRequest,
    GetPolicyTagRequest,
    GetTaxonomyRequest,
    ListPolicyTagsRequest,
    ListPolicyTagsResponse,
    ListTaxonomiesRequest,
    ListTaxonomiesResponse,
    PolicyTag,
    Taxonomy,
    UpdatePolicyTagRequest,
    UpdateTaxonomyRequest,
)
from .policytagmanagerserialization import (
    ExportTaxonomiesRequest,
    ExportTaxonomiesResponse,
    ImportTaxonomiesRequest,
    ImportTaxonomiesResponse,
    InlineSource,
    SerializedPolicyTag,
    SerializedTaxonomy,
)
from .schema import (
    ColumnSchema,
    Schema,
)
from .search import (
    SearchCatalogResult,
    SearchResultType,
)
from .table_spec import (
    BigQueryDateShardedSpec,
    BigQueryTableSpec,
    TableSpec,
    ViewSpec,
    TableSourceType,
)
from .tags import (
    FieldType,
    Tag,
    TagField,
    TagTemplate,
    TagTemplateField,
)
from .timestamps import SystemTimestamps

__all__ = (
    "IntegratedSystem",
    "CreateEntryGroupRequest",
    "CreateEntryRequest",
    "CreateTagRequest",
    "CreateTagTemplateFieldRequest",
    "CreateTagTemplateRequest",
    "DeleteEntryGroupRequest",
    "DeleteEntryRequest",
    "DeleteTagRequest",
    "DeleteTagTemplateFieldRequest",
    "DeleteTagTemplateRequest",
    "Entry",
    "EntryGroup",
    "GetEntryGroupRequest",
    "GetEntryRequest",
    "GetTagTemplateRequest",
    "ListEntriesRequest",
    "ListEntriesResponse",
    "ListEntryGroupsRequest",
    "ListEntryGroupsResponse",
    "ListTagsRequest",
    "ListTagsResponse",
    "LookupEntryRequest",
    "RenameTagTemplateFieldRequest",
    "SearchCatalogRequest",
    "SearchCatalogResponse",
    "UpdateEntryGroupRequest",
    "UpdateEntryRequest",
    "UpdateTagRequest",
    "UpdateTagTemplateFieldRequest",
    "UpdateTagTemplateRequest",
    "EntryType",
    "GcsFilesetSpec",
    "GcsFileSpec",
    "CreatePolicyTagRequest",
    "CreateTaxonomyRequest",
    "DeletePolicyTagRequest",
    "DeleteTaxonomyRequest",
    "GetPolicyTagRequest",
    "GetTaxonomyRequest",
    "ListPolicyTagsRequest",
    "ListPolicyTagsResponse",
    "ListTaxonomiesRequest",
    "ListTaxonomiesResponse",
    "PolicyTag",
    "Taxonomy",
    "UpdatePolicyTagRequest",
    "UpdateTaxonomyRequest",
    "ExportTaxonomiesRequest",
    "ExportTaxonomiesResponse",
    "ImportTaxonomiesRequest",
    "ImportTaxonomiesResponse",
    "InlineSource",
    "SerializedPolicyTag",
    "SerializedTaxonomy",
    "ColumnSchema",
    "Schema",
    "SearchCatalogResult",
    "SearchResultType",
    "BigQueryDateShardedSpec",
    "BigQueryTableSpec",
    "TableSpec",
    "ViewSpec",
    "TableSourceType",
    "FieldType",
    "Tag",
    "TagField",
    "TagTemplate",
    "TagTemplateField",
    "SystemTimestamps",
)
